[![CircleCI](https://circleci.com/gh/okomestudio/ghwh.svg?style=svg)](https://circleci.com/gh/okomestudio/ghwh)


# ghwh

GitHub webhook handler app.


## Running Tests

```bash
pip install -e .[dev] && pytest --cov=src/ --cov-report=term-missing tests/
```
